==> haskell-arrows-0.4.4.2-100-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 arrows
version:              0.4.4.2
visibility:           public
id:                   arrows-0.4.4.2-1vGB88PkNyg5PI585VJOAD
key:                  arrows-0.4.4.2-1vGB88PkNyg5PI585VJOAD
license:              BSD-3-Clause
maintainer:           Ross Paterson <R.Paterson@city.ac.uk>
author:               Ross Paterson <R.Paterson@city.ac.uk>
homepage:             http://www.haskell.org/arrows/
synopsis:             Arrow classes and transformers
description:
    Several classes that extend the Arrow class, and some
    transformers that implement or lift these classes.

category:             Control
abi:                  67e692b486e4af9d9731bbd15f805421
exposed:              True
exposed-modules:
    Control.Arrow.Operations Control.Arrow.Transformer
    Control.Arrow.Transformer.All Control.Arrow.Transformer.Automaton
    Control.Arrow.Transformer.CoState Control.Arrow.Transformer.Error
    Control.Arrow.Transformer.Reader Control.Arrow.Transformer.State
    Control.Arrow.Transformer.Static Control.Arrow.Transformer.Stream
    Control.Arrow.Transformer.Writer

hidden-modules:       Control.Arrow.Internals
import-dirs:          /usr/lib/ghc-9.0.2/site-local/arrows-0.4.4.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/arrows-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arrows
hs-libraries:         HSarrows-0.4.4.2-1vGB88PkNyg5PI585VJOAD
depends:              Stream-0.4.7.2-GHNBr7SEIeX1BmVJHLOKzb base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-arrows/html/arrows.haddock
haddock-html:         /usr/share/doc/haskell-arrows/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-arrows-0.4.4.2-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 arrows
version:              0.4.4.2
visibility:           public
id:                   arrows-0.4.4.2-FKTyowO02fkL1rl37VQTFy
key:                  arrows-0.4.4.2-FKTyowO02fkL1rl37VQTFy
license:              BSD-3-Clause
maintainer:           Ross Paterson <R.Paterson@city.ac.uk>
author:               Ross Paterson <R.Paterson@city.ac.uk>
homepage:             http://www.haskell.org/arrows/
synopsis:             Arrow classes and transformers
description:
    Several classes that extend the Arrow class, and some
    transformers that implement or lift these classes.

category:             Control
abi:                  8412dd73571159f473a766d3421db3d2
exposed:              True
exposed-modules:
    Control.Arrow.Operations Control.Arrow.Transformer
    Control.Arrow.Transformer.All Control.Arrow.Transformer.Automaton
    Control.Arrow.Transformer.CoState Control.Arrow.Transformer.Error
    Control.Arrow.Transformer.Reader Control.Arrow.Transformer.State
    Control.Arrow.Transformer.Static Control.Arrow.Transformer.Stream
    Control.Arrow.Transformer.Writer

hidden-modules:       Control.Arrow.Internals
import-dirs:          /usr/lib/ghc-9.0.2/site-local/arrows-0.4.4.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/arrows-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arrows
hs-libraries:         HSarrows-0.4.4.2-FKTyowO02fkL1rl37VQTFy
depends:              Stream-0.4.7.2-EcqNIlnZYxeEKWmTkOgKIz base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-arrows/html/arrows.haddock
haddock-html:         /usr/share/doc/haskell-arrows/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
